@@ -20,7 +20,7 @@ package MongoDB::GridFSBucket;
 # ABSTRACT: A file storage abstraction
 
 use version;
-our $VERSION = 'v1.8.0';
+our $VERSION = 'v1.8.1';
 
 use Moo;
 use MongoDB::GridFSBucket::DownloadStream;
@@ -573,7 +573,7 @@ MongoDB::GridFSBucket - A file storage abstraction
 
 =head1 VERSION
 
-version v1.8.0
+version v1.8.1
 
 =head1 SYNOPSIS
 
@@ -635,7 +635,7 @@ md5 – a hash of the contents of the stored file
 
 =item *
 
-filename – the name of this stored file; this does not need to be unique
+filename – the name of this stored file; the combination of filename and uploadDate (millisecond resolution) must be unique
 
 =item *
 
@@ -921,7 +921,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by MongoDB, Inc.
+This software is Copyright (c) 2018 by MongoDB, Inc.
 
 This is free software, licensed under:
 
