@@ -16,21 +16,22 @@
 
 use strict;
 use warnings;
+
 package MongoDB::Op::_GetMore;
 
 # Encapsulate a cursor fetch operation; returns raw results object
 # (after inflation from BSON)
 
 use version;
-our $VERSION = 'v1.8.0';
+our $VERSION = 'v1.8.1';
 
 use Moo;
 
 use MongoDB::_Protocol;
 use Types::Standard qw(
-    Maybe
-    Any
-    Num
+  Maybe
+  Any
+  Num
 );
 
 use namespace::clean;
@@ -48,8 +49,8 @@ has batch_size => (
 );
 
 has max_time_ms => (
-    is       => 'ro',
-    isa      => Maybe[Num],
+    is  => 'ro',
+    isa => Num,
 );
 
 with $_ for qw(
@@ -64,8 +65,8 @@ sub execute {
 
     my $res =
         $link->accepts_wire_version(4)
-      ? $self->_command_get_more( $link )
-      : $self->_legacy_get_more( $link );
+      ? $self->_command_get_more($link)
+      : $self->_legacy_get_more($link);
 
     return $res;
 }
@@ -74,25 +75,25 @@ sub _command_get_more {
     my ( $self, $link ) = @_;
 
     my $cmd = [
-        getMore         => $self->cursor_id,
-        collection      => $self->coll_name,
-        $self->batch_size > 0 ? (batchSize => $self->batch_size) : (),
-        defined $self->max_time_ms ? (maxTimeMS => $self->max_time_ms) : (),
+        getMore    => $self->cursor_id,
+        collection => $self->coll_name,
+        ( $self->batch_size > 0 ? ( batchSize => $self->batch_size )  : () ),
+        ( $self->max_time_ms    ? ( maxTimeMS => $self->max_time_ms ) : () ),
     ];
 
     my $op = MongoDB::Op::_Command->_new(
-        db_name         => $self->db_name,
-        query           => $cmd,
-        query_flags     => {},
-        bson_codec      => $self->bson_codec,
+        db_name     => $self->db_name,
+        query       => $cmd,
+        query_flags => {},
+        bson_codec  => $self->bson_codec,
     );
 
-    my $c = $op->execute( $link )->output->{cursor};
+    my $c = $op->execute($link)->output->{cursor};
     my $batch = $c->{nextBatch} || [];
 
     return {
-        cursor_id       => $c->{id} || 0,
-        flags           => {},
+        cursor_id => $c->{id} || 0,
+        flags => {},
         starting_from   => 0,
         number_returned => scalar @$batch,
         docs            => $batch,
